@@ -305,7 +305,6 @@ novak_index <- function(iadf, model, po = NULL, method = "difference"){
 #'   size? Trees (2015) 29: 237. doi:10.1007/s00468-014-1108-9
 #' @export
 #' @seealso  \code{\link{campelo_chapman}}, \code{\link{campelo_index}}
-#' @importFrom rlang .data
 #' @importFrom dplyr %>%
 #' @examples
 #' data('example_iadf')
@@ -313,89 +312,45 @@ novak_index <- function(iadf, model, po = NULL, method = "difference"){
 #' model <- campelo_chapman(campelo_freq(example_iadf, example_rwl))
 #' campelo_index(example_iadf, example_rwl, model)
 campelo_freq <- function(iadf, rwl, n = 20){
-  if (utils::packageVersion("dplyr") > "0.5.0") {
-    if (!is.data.frame(iadf)) {
-      stop("iadf has to be a data.frame")
-    }
+  
+  year <- NULL # silence R CMD check
 
-    if (!is.data.frame(rwl)) {
-      stop("rwl has to be a data.frame")
-    }
-
-    if (!all(as.matrix(iadf) %in% c(0, 1, NA))) {
-      stop("iadf must only contain 0, 1, and NA values")
-    }
-
-    nclass <- rlang::quo(n)
-
-    iadf_tidy <- iadf %>%
-      tibble::rownames_to_column("year") %>%
-      tibble::as_tibble() %>%
-      dplyr::mutate(year = as.integer(.data$year)) %>%
-      tidyr::gather("series", "iadf", -.data$year) %>%
-      dplyr::filter(!is.na(.data$iadf))
-
-    rwl_tidy <- tidy_rwl(rwl) %>%
-      dplyr::mutate(class = cut(.data$rwl, !!nclass))
-
-    tmp <- dplyr::left_join(iadf_tidy, rwl_tidy, by = c("year", "series"))
-
-    out <- tmp %>%
-      dplyr::group_by(.data$class) %>%
-      dplyr::summarise(freq = mean(.data$iadf, na.rm = TRUE),
-                       class.mean.rwl = mean(.data$rwl, na.rm = TRUE),
-                       sample.depth = length(.data$iadf)) %>%
-      as.data.frame
-
-    class(out) <- c("data.frame", "campelo.freq")
-
-    return(out)
-
-  } else {# keep code for dplyr < 0.6 for backwards compatibility
-
-    if (!is.data.frame(iadf)) {
-      stop("iadf has to be a data.frame")
-    }
-
-    if (!is.data.frame(rwl)) {
-      stop("rwl has to be a data.frame")
-    }
-
-    if (!all(as.matrix(iadf) %in% c(0, 1, NA))) {
-      stop("iadf must only contain 0, 1, and NA values")
-    }
-
-    iadf_tidy <- iadf %>%
-      tibble::rownames_to_column("year") %>%
-      tibble::as_tibble() %>%
-      dplyr::mutate_(.dots = setNames(
-        list(lazyeval::interp(~as.numeric(var),
-                              var = as.name("year"))), "year")) %>%
-      tidyr::gather_("series", "iadf",
-                     dplyr::select_vars_(names(.), names(.),
-                                         exclude = "year")) %>%
-      dplyr::filter_(lazyeval::interp(~(!is.na(nam)), nam = as.name("iadf")))
-
-    rwl_tidy <- tidy_rwl(rwl) %>%
-      dplyr::mutate_(.dots = setNames(
-        list(lazyeval::interp(~cut(r, n),
-                              r = as.name("rwl"))), "class"))
-
-    tmp <- dplyr::left_join(iadf_tidy, rwl_tidy, by = c("year", "series"))
-
-    freq <- tapply(tmp[["iadf"]], tmp[["class"]],
-                   function(y) mean(y, na.rm = TRUE))
-    class_mean <- tapply(tmp[["rwl"]], tmp[["class"]],
-                         function(y) mean(y, na.rm = TRUE))
-    sample_depth <- tapply(tmp[["iadf"]], tmp[["class"]],
-                           function(y) length(na.omit(y)))
-    out <- data.frame(class = factor(names(freq), levels = names(freq)),
-                      freq = as.vector(freq),
-                      class.mean.rwl = as.vector(class_mean),
-                      sample.depth = as.vector(sample_depth))
-    class(out) <- c("data.frame", "campelo.freq")
-    return(out)
+  if (!is.data.frame(iadf)) {
+    stop("iadf has to be a data.frame")
   }
+
+  if (!is.data.frame(rwl)) {
+    stop("rwl has to be a data.frame")
+  }
+
+  if (!all(as.matrix(iadf) %in% c(0, 1, NA))) {
+    stop("iadf must only contain 0, 1, and NA values")
+  }
+
+  nclass <- rlang::quo(n)
+
+  iadf_tidy <- iadf %>%
+    tibble::rownames_to_column("year") %>%
+    tibble::as_tibble() %>%
+    dplyr::mutate(year = as.integer(year)) %>%
+    tidyr::gather("series", "iadf", -year) %>%
+    dplyr::filter(!is.na(iadf))
+
+  rwl_tidy <- tidy_rwl(rwl) %>%
+    dplyr::mutate(class = cut(rwl, !!nclass))
+
+  tmp <- dplyr::left_join(iadf_tidy, rwl_tidy, by = c("year", "series"))
+
+  out <- tmp %>%
+    dplyr::group_by(class) %>%
+    dplyr::summarise(freq = mean(iadf, na.rm = TRUE),
+                     class.mean.rwl = mean(rwl, na.rm = TRUE),
+                     sample.depth = length(iadf)) %>%
+    as.data.frame
+
+  class(out) <- c("data.frame", "campelo.freq")
+
+  return(out)
 }
 
 # campelo chapman find start values --------------------------------------------
@@ -528,7 +483,6 @@ campelo_chapman <- function(campelo_freq_object, min.n = 15, start = NULL,
 #' @return a data frame
 #' @export
 #' @seealso \code{\link{campelo_freq}}, \code{\link{campelo_chapman}}
-#' @importFrom rlang .data
 #' @importFrom dplyr %>%
 #' @references
 #'   Campelo, F., Vieira, J., Battipaglia, G. et al. Which matters most for the
@@ -541,94 +495,45 @@ campelo_chapman <- function(campelo_freq_object, min.n = 15, start = NULL,
 #' campelo_index(example_iadf, example_rwl, model)
 campelo_index <- function(iadf, rwl, model){
 
-  if (utils::packageVersion("dplyr") > "0.5.0") {
-
-    if (!is.data.frame(iadf)) {
-      stop("iadf has to be a data.frame")
-    }
-
-    if (!is.data.frame(rwl)) {
-      stop("rwl has to be a data.frame")
-    }
-
-    if (!all(as.matrix(iadf) %in% c(0, 1, NA))) {
-      stop("iadf must only contain 0, 1, and NA values")
-    }
-
-    iadf_tidy <- iadf %>%
-      tibble::rownames_to_column("year") %>%
-      tibble::as_tibble() %>%
-      dplyr::mutate(year = as.numeric(.data$year)) %>%
-      tidyr::gather("series", "iadf", -.data$year) %>%
-      dplyr::filter(!is.na(.data$iadf))
-
-    rwl_tidy <- tidy_rwl(rwl)
-
-    tmp <- dplyr::left_join(iadf_tidy, rwl_tidy, by = c("year", "series")) %>%
-      dplyr::mutate(prediction =
-                      stats::predict(model,
-                                     newdata = list(ring_width = .data$rwl))) %>%
-      dplyr::mutate(index = .data$iadf - .data$prediction) %>%
-      dplyr::select("year", "series", "index") %>%
-      tidyr::spread("series", "index")
-
-    mean_index <- cbind(tmp["year"], rowMeans(dplyr::select_(tmp, "-year"),
-                                              na.rm = TRUE))
-    names(mean_index) <- c("year", "index")
-
-    spline <- dplR::ffcsaps(mean_index[["index"]])
-    detrend_index <- dplyr::mutate(mean_index,
-                                   detrended_index = .data$index - spline)
-
-    return(detrend_index)
-
-  } else {#keep code for dplyr < 0.6 for backwards compatibility
-
-    if (!is.data.frame(iadf)) {
-      stop("iadf has to be a data.frame")
-    }
-
-    if (!is.data.frame(rwl)) {
-      stop("rwl has to be a data.frame")
-    }
-
-    if (!all(as.matrix(iadf) %in% c(0, 1, NA))) {
-      stop("iadf must only contain 0, 1, and NA values")
-    }
-
-    iadf_tidy <- iadf %>%
-      tibble::rownames_to_column("year") %>%
-      tibble::as_tibble() %>%
-      dplyr::mutate_(.dots = setNames(
-        list(lazyeval::interp(~as.numeric(var),
-                              var = as.name("year"))), "year")) %>%
-      tidyr::gather_("series", "iadf",
-                     dplyr::select_vars_(names(.), names(.),
-                                         exclude = "year")) %>%
-      dplyr::filter_(lazyeval::interp(~(!is.na(nam)), nam = as.name("iadf")))
-
-    rwl_tidy <- tidy_rwl(rwl)
-
-    tmp <- dplyr::left_join(iadf_tidy, rwl_tidy, by = c("year", "series")) %>%
-      dplyr::mutate_(.dots = setNames(list(
-        lazyeval::interp(~predict(md, newdata = list(ring_width = .[["rwl"]])),
-                         md = as.name("model"))), "prediction")) %>%
-      dplyr::mutate_(.dots = setNames(list(
-        lazyeval::interp(~ia - pr, ia = as.name("iadf"),
-                         pr = as.name("prediction"))), "index")) %>%
-      dplyr::select_("year", "series", "index") %>%
-      tidyr::spread_("series", "index")
-
-    mean_index <- cbind(tmp["year"], rowMeans(dplyr::select_(tmp, "-year"),
-                                              na.rm = TRUE))
-    names(mean_index) <- c("year", "index")
-
-    spline <- dplR::ffcsaps(mean_index[["index"]])
-    detrend_index <- dplyr::mutate_(mean_index, .dots = setNames(list(
-      lazyeval::interp(~ i - s, i = as.name("index"), s = as.name("spline"))),
-      "detrended_index"))
-
-    return(detrend_index)
+  # silence R CMD check
+  year <- prediction <- index <- NULL
 
+  if (!is.data.frame(iadf)) {
+    stop("iadf has to be a data.frame")
   }
+
+  if (!is.data.frame(rwl)) {
+    stop("rwl has to be a data.frame")
+  }
+
+  if (!all(as.matrix(iadf) %in% c(0, 1, NA))) {
+    stop("iadf must only contain 0, 1, and NA values")
+  }
+
+  iadf_tidy <- iadf %>%
+    tibble::rownames_to_column("year") %>%
+    tibble::as_tibble() %>%
+    dplyr::mutate(year = as.numeric(year)) %>%
+    tidyr::gather("series", "iadf", -year) %>%
+    dplyr::filter(!is.na(iadf))
+
+  rwl_tidy <- tidy_rwl(rwl)
+
+  tmp <- dplyr::left_join(iadf_tidy, rwl_tidy, by = c("year", "series")) %>%
+    dplyr::mutate(prediction =
+                    stats::predict(model,
+                                    newdata = list(ring_width = rwl))) %>%
+    dplyr::mutate(index = iadf - prediction) %>%
+    dplyr::select("year", "series", "index") %>%
+    tidyr::spread("series", "index")
+
+  mean_index <- cbind(tmp["year"], rowMeans(dplyr::select(tmp, -year),
+                                            na.rm = TRUE))
+  names(mean_index) <- c("year", "index")
+
+  spline <- dplR::caps(mean_index[["index"]])
+  detrend_index <- dplyr::mutate(mean_index,
+                                  detrended_index = index - spline)
+
+  return(detrend_index)
 }
